/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tySequence__SHVxAqOYtIy7teT1q4s0zQ tySequence__SHVxAqOYtIy7teT1q4s0zQ;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow;
typedef struct tyObject_Table__6nOsw5R7jH72bux7HSST9bg tyObject_Table__6nOsw5R7jH72bux7HSST9bg;
typedef struct tySequence__diqJJ1bWuFP7M6rQDS9cBLQ tySequence__diqJJ1bWuFP7M6rQDS9cBLQ;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA;
typedef struct tySequence__sII3pVVRkIdBZ2HDPdZddA tySequence__sII3pVVRkIdBZ2HDPdZddA;
typedef struct tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A;
typedef struct tySequence__WPcy3bORPBFlmk2KIq2pbQ tySequence__WPcy3bORPBFlmk2KIq2pbQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q;
typedef struct tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A;
typedef struct tySequence__vhmj4KkIKPinmRXny9c2Q6Q tySequence__vhmj4KkIKPinmRXny9c2Q6Q;
typedef struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ;
typedef struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ tySequence__XUL1TrMU0tgXmaMFCIYgFQ;
typedef struct tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__KjgUMUjT3LUKOFIK4xt5ug tySequence__KjgUMUjT3LUKOFIK4xt5ug;
typedef struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg tySequence__WwUFq9cJ2xKRlsAWVEHyPRg;
typedef struct tySequence__oUyaggHmIX9bpJcMeoG6lpA tySequence__oUyaggHmIX9bpJcMeoG6lpA;
typedef struct tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw tySequence__jwzrUFjG9akTIJTBBFvvqxw;
typedef struct tyTuple__FxkU4d1VDodDMc9ah6Mbagw tyTuple__FxkU4d1VDodDMc9ah6Mbagw;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TBlock__GFhahvekTq3dDOkWyhchMA tyObject_TBlock__GFhahvekTq3dDOkWyhchMA;
typedef struct tyTuple__Iz0jrTw3w7v6sMzjrqs0nA tyTuple__Iz0jrTw3w7v6sMzjrqs0nA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__4keOEuB8uAwYehpErwqI9ag tyTuple__4keOEuB8uAwYehpErwqI9ag;
typedef struct tyTuple__wROVfG5RQYpjEAhvO3LqdQ tyTuple__wROVfG5RQYpjEAhvO3LqdQ;
typedef struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA tyTuple__a1QJSSO0LTGR9bFH59c2xGCA;
typedef struct tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg;
typedef struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_Table__6nOsw5R7jH72bux7HSST9bg {
tySequence__diqJJ1bWuFP7M6rQDS9cBLQ* data;
NI counter;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mainModProcs;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mainModInit;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* otherModsInit;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mainDatInit;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mapping;
tySequence__SHVxAqOYtIy7teT1q4s0zQ* modules;
tySequence__SHVxAqOYtIy7teT1q4s0zQ* modulesClosed;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* forwardedProcs;
tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* generatedHeader;
tyObject_Table__6nOsw5R7jH72bux7HSST9bg typeInfoMarker;
tyObject_Table__6nOsw5R7jH72bux7HSST9bg typeInfoMarkerV2;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
NI strVersion;
NI seqVersion;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nimtv;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* nimtvDeps;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg nimtvDeclared;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__pujFC2IN5RzE4MXkqaMD9aQ[20];
typedef NU8 tySet_tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA {
tySequence__sII3pVVRkIdBZ2HDPdZddA* data;
NI counter;
};
struct tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A {
tySequence__WPcy3bORPBFlmk2KIq2pbQ* data;
NI counter;
};
struct tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A {
NI counter;
tySequence__vhmj4KkIKPinmRXny9c2Q6Q* data;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__MxT2Arb3Nlp7V9bRITO3dvg[10];
struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ {
tySequence__XUL1TrMU0tgXmaMFCIYgFQ* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw {
NIM_BOOL enabled;
FILE* f;
NimStringDesc* buf;
NimStringDesc* filename;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* syms;
};
struct tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyArray__pujFC2IN5RzE4MXkqaMD9aQ s;
tySet_tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q flags;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
NimStringDesc* filename;
NimStringDesc* cfilename;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpBase;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA typeCache;
tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A typeABICache;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA forwTypeCache;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg declaredThings;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg declaredProtos;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* headerFiles;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA typeInfoMarker;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA typeInfoMarkerV2;
tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* initProc;
tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* preInitProc;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* hcrCreateTypeInfosProc;
NIM_BOOL inHcrInitGuard;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeStack;
tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A dataCache;
NI typeNodes;
NI nimTypes;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typeNodesName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nimTypesName;
NI labels;
tyArray__MxT2Arb3Nlp7V9bRITO3dvg extensionLoaders;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* injectStmt;
tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ sigConflicts;
tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g;
tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw ndi;
};
typedef NU8 tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q;
typedef NU8 tySet_tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
struct tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg {
tySequence__jwzrUFjG9akTIJTBBFvvqxw* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
tySet_tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ flags;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q currLineInfo;
tySequence__KjgUMUjT3LUKOFIK4xt5ug* nestedTryStmts;
tySequence__WwUFq9cJ2xKRlsAWVEHyPRg* finallySafePoints;
NI labels;
tySequence__oUyaggHmIX9bpJcMeoG6lpA* blocks;
NI breakIdx;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* module;
NI withinLoop;
NI splitDecls;
NI withinTryWithExcept;
NI withinBlockLeaveActions;
tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg sigConflicts;
};
typedef NU8 tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ;
struct tyTuple__FxkU4d1VDodDMc9ah6Mbagw {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
NIM_BOOL Field1;
NI Field2;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__c9b9aKKmyKnqxZD8lAny45jg[3];
struct tyObject_TBlock__GFhahvekTq3dDOkWyhchMA {
NI id;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* label;
tyArray__c9b9aKKmyKnqxZD8lAny45jg sections;
NIM_BOOL isLoop;
NI16 nestedTryStmts;
NI16 nestedExceptStmts;
NI16 frameLen;
};
struct tyTuple__Iz0jrTw3w7v6sMzjrqs0nA {
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__4keOEuB8uAwYehpErwqI9ag {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyTuple__Iz0jrTw3w7v6sMzjrqs0nA Field2;
};
struct tyTuple__wROVfG5RQYpjEAhvO3LqdQ {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field2;
};
struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
};
struct tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg {
NI h;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
NI val;
};
struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg {
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field0;
NI Field1;
};
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
NimStringDesc* Field0;
NI Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__KjgUMUjT3LUKOFIK4xt5ug {
  TGenericSeq Sup;
  tyTuple__FxkU4d1VDodDMc9ah6Mbagw data[SEQ_DECL_SIZE];
};
struct tySequence__oUyaggHmIX9bpJcMeoG6lpA {
  TGenericSeq Sup;
  tyObject_TBlock__GFhahvekTq3dDOkWyhchMA data[SEQ_DECL_SIZE];
};
struct tySequence__SHVxAqOYtIy7teT1q4s0zQ {
  TGenericSeq Sup;
  tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* data[SEQ_DECL_SIZE];
};
struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg {
  TGenericSeq Sup;
  tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__diqJJ1bWuFP7M6rQDS9cBLQ {
  TGenericSeq Sup;
  tyTuple__4keOEuB8uAwYehpErwqI9ag data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__sII3pVVRkIdBZ2HDPdZddA {
  TGenericSeq Sup;
  tyTuple__wROVfG5RQYpjEAhvO3LqdQ data[SEQ_DECL_SIZE];
};
struct tySequence__WPcy3bORPBFlmk2KIq2pbQ {
  TGenericSeq Sup;
  tyTuple__a1QJSSO0LTGR9bFH59c2xGCA data[SEQ_DECL_SIZE];
};
struct tySequence__vhmj4KkIKPinmRXny9c2Q6Q {
  TGenericSeq Sup;
  tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg data[SEQ_DECL_SIZE];
};
struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ {
  TGenericSeq Sup;
  tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg data[SEQ_DECL_SIZE];
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw {
  TGenericSeq Sup;
  tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__KjgUMUjT3LUKOFIK4xt5ug)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__oUyaggHmIX9bpJcMeoG6lpA)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__pAZKtoy4786BGdQWfW2Iqg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__NkKlBfvvsMUW70DxvxLVIg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__SHVxAqOYtIy7teT1q4s0zQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__1nYo7zUSsqu0chwXZGtykg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initTable__22cYO7U9aPu9aJmxAg0EDCBg)(NI initialSize, tyObject_Table__6nOsw5R7jH72bux7HSST9bg* Result);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__c8ZqFh8t3EqhDNTipW6ekQ)(NI initialSize, tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg* Result);
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);

/* section: NIM_merge_DATA */
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__CpP4eJLbv5ZwofQXpESuGA_;
extern TNimType NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_;
extern TNimType NTI__Hb6rFM0ecvtlLf2kv9aU75w_;
N_LIB_PRIVATE TNimType NTI__9cG6VsX22pOhho6kxyhFVow_;
N_LIB_PRIVATE TNimType NTI__pujFC2IN5RzE4MXkqaMD9aQ_;
N_LIB_PRIVATE TNimType NTI__9c7EibnXBApMXwrQsaaMb6Q_;
N_LIB_PRIVATE TNimType NTI__OeiqbEYQJbV4hSslyTd4XQ_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTI__gZ3EYQdz9coOB7ngN9a1cqwA_;
extern TNimType NTI__LWqBPbJi8sAUtgObUDu34A_;
extern TNimType NTI__PQrmFm4BXFkFSVOUl1ojSg_;
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTI__g7nhmFb7KltrkyRKuP8k2Q_;
N_LIB_PRIVATE TNimType NTI__LgBeaca7tT1nUR7RL1RjPQ_;
N_LIB_PRIVATE TNimType NTI__7AbOk6EDToLYuZGJ19cmZSg_;
extern TNimType NTI__WGx4rAexNXnczy1Avn646Q_;
N_LIB_PRIVATE TNimType NTI__FxkU4d1VDodDMc9ah6Mbagw_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__hLlQjbV9bLNq5PFxYcqacsA_;
N_LIB_PRIVATE TNimType NTI__KjgUMUjT3LUKOFIK4xt5ug_;
extern TNimType NTI__WwUFq9cJ2xKRlsAWVEHyPRg_;
N_LIB_PRIVATE TNimType NTI__GFhahvekTq3dDOkWyhchMA_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__c9b9aKKmyKnqxZD8lAny45jg_;
extern TNimType NTI__kDPg4wXyR8DDyA0MeEjIsw_;
N_LIB_PRIVATE TNimType NTI__oUyaggHmIX9bpJcMeoG6lpA_;
extern TNimType NTI__7MnKRybmCNh5j9bDRLMkxLw_;
extern TNimType NTI__chlLjy9bvnFM9b9bSZfiIkyGg_;
N_LIB_PRIVATE TNimType NTI__pAZKtoy4786BGdQWfW2Iqg_;
extern TNimType NTI__Ef05srmQTDulnBdXR4Ja6Q_;
extern TNimType NTI__wN7B39cKxLpMkvKNm9bduZ0A_;
N_LIB_PRIVATE TNimType NTI__MxT2Arb3Nlp7V9bRITO3dvg_;
extern TNimType NTI__tUMxxU9cRgLolsrW9b7IBGsQ_;
extern TNimType NTI__9cEuXfAnHp9bnWFK409cMtsEw_;
N_LIB_PRIVATE TNimType NTI__NkKlBfvvsMUW70DxvxLVIg_;
N_LIB_PRIVATE TNimType NTI__SHVxAqOYtIy7teT1q4s0zQ_;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
N_LIB_PRIVATE TNimType NTI__Iz0jrTw3w7v6sMzjrqs0nA_;
extern TNimType NTI__6nOsw5R7jH72bux7HSST9bg_;
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
extern TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
N_LIB_PRIVATE TNimType NTI__1nYo7zUSsqu0chwXZGtykg_;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__KjgUMUjT3LUKOFIK4xt5ug)(void* p, NI op) {
	tySequence__KjgUMUjT3LUKOFIK4xt5ug* a;
	NI T1_;
	a = (tySequence__KjgUMUjT3LUKOFIK4xt5ug*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__oUyaggHmIX9bpJcMeoG6lpA)(void* p, NI op) {
	tySequence__oUyaggHmIX9bpJcMeoG6lpA* a;
	NI T1_;
	NI T2_;
	a = (tySequence__oUyaggHmIX9bpJcMeoG6lpA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].label, op);
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 3; T2_++) {
	nimGCvisit((void*)a->data[T1_].sections[T2_], op);
	}
	}
}
static N_NIMCALL(void, Marker_tyRef__pAZKtoy4786BGdQWfW2Iqg)(void* p, NI op) {
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* a;
	a = (tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q*)p;
	nimGCvisit((void*)(*a).prc, op);
	nimGCvisit((void*)(*a).nestedTryStmts, op);
	nimGCvisit((void*)(*a).finallySafePoints, op);
	nimGCvisit((void*)(*a).blocks, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).sigConflicts.data, op);
}
static N_NIMCALL(void, Marker_tyRef__NkKlBfvvsMUW70DxvxLVIg)(void* p, NI op) {
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* a;
	NI T1_;
	NI T2_;
	NI T3_;
	NI T4_;
	a = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 20; T1_++) {
	nimGCvisit((void*)(*a).s[T1_], op);
	}
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).filename, op);
	nimGCvisit((void*)(*a).cfilename, op);
	nimGCvisit((void*)(*a).tmpBase, op);
	nimGCvisit((void*)(*a).typeCache.data, op);
	nimGCvisit((void*)(*a).typeABICache.data, op);
	nimGCvisit((void*)(*a).forwTypeCache.data, op);
	nimGCvisit((void*)(*a).declaredThings.head, op);
	nimGCvisit((void*)(*a).declaredThings.data, op);
	T2_ = (NI)0;
	nimGCvisit((void*)(*a).declaredProtos.head, op);
	nimGCvisit((void*)(*a).declaredProtos.data, op);
	T3_ = (NI)0;
	nimGCvisit((void*)(*a).headerFiles, op);
	nimGCvisit((void*)(*a).typeInfoMarker.data, op);
	nimGCvisit((void*)(*a).typeInfoMarkerV2.data, op);
	nimGCvisit((void*)(*a).initProc, op);
	nimGCvisit((void*)(*a).preInitProc, op);
	nimGCvisit((void*)(*a).hcrCreateTypeInfosProc, op);
	nimGCvisit((void*)(*a).typeStack, op);
	nimGCvisit((void*)(*a).dataCache.data, op);
	nimGCvisit((void*)(*a).typeNodesName, op);
	nimGCvisit((void*)(*a).nimTypesName, op);
	T4_ = (NI)0;
	for (T4_ = 0; T4_ < 10; T4_++) {
	nimGCvisit((void*)(*a).extensionLoaders[T4_], op);
	}
	nimGCvisit((void*)(*a).injectStmt, op);
	nimGCvisit((void*)(*a).sigConflicts.data, op);
	nimGCvisit((void*)(*a).g, op);
	nimGCvisit((void*)(*a).ndi.buf, op);
	nimGCvisit((void*)(*a).ndi.filename, op);
	nimGCvisit((void*)(*a).ndi.syms, op);
}
static N_NIMCALL(void, Marker_tySequence__SHVxAqOYtIy7teT1q4s0zQ)(void* p, NI op) {
	tySequence__SHVxAqOYtIy7teT1q4s0zQ* a;
	NI T1_;
	a = (tySequence__SHVxAqOYtIy7teT1q4s0zQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tyRef__1nYo7zUSsqu0chwXZGtykg)(void* p, NI op) {
	tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* a;
	NI T1_;
	a = (tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*)p;
	nimGCvisit((void*)(*a).mainModProcs, op);
	nimGCvisit((void*)(*a).mainModInit, op);
	nimGCvisit((void*)(*a).otherModsInit, op);
	nimGCvisit((void*)(*a).mainDatInit, op);
	nimGCvisit((void*)(*a).mapping, op);
	nimGCvisit((void*)(*a).modules, op);
	nimGCvisit((void*)(*a).modulesClosed, op);
	nimGCvisit((void*)(*a).forwardedProcs, op);
	nimGCvisit((void*)(*a).generatedHeader, op);
	nimGCvisit((void*)(*a).typeInfoMarker.data, op);
	nimGCvisit((void*)(*a).typeInfoMarkerV2.data, op);
	nimGCvisit((void*)(*a).config, op);
	nimGCvisit((void*)(*a).graph, op);
	nimGCvisit((void*)(*a).nimtv, op);
	nimGCvisit((void*)(*a).nimtvDeps, op);
	nimGCvisit((void*)(*a).nimtvDeclared.head, op);
	nimGCvisit((void*)(*a).nimtvDeclared.data, op);
	T1_ = (NI)0;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*, newModuleList__pKl1ntXN7hbkEFOmcSlHSg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* result;
	tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* T1_;
	result = (tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*)0;
	T1_ = (tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*)0;
	T1_ = (tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*) newObj((&NTI__1nYo7zUSsqu0chwXZGtykg_), sizeof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA));
	(*T1_).Sup.m_type = (&NTI__CpP4eJLbv5ZwofQXpESuGA_);
	initTable__22cYO7U9aPu9aJmxAg0EDCBg(((NI) 32), (&(*T1_).typeInfoMarker));
	asgnRef((void**) (&(*T1_).config), (*g).config);
	asgnRef((void**) (&(*T1_).graph), g);
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*T1_).nimtvDeclared));
	result = T1_;
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q*, newProc__r9c9cj4fW68RhY7ht9btSvB8w)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* module) {
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* result;
	result = (tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q*)0;
	result = (tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q*) newObj((&NTI__pAZKtoy4786BGdQWfW2Iqg_), sizeof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q));
	asgnRef((void**) (&(*result).prc), prc);
	asgnRef((void**) (&(*result).module), module);
	{
		if (!!((prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		(*result).options = (*prc).options;
	}
	goto LA1_;
	LA3_: ;
	{
		(*result).options = (*(*(*module).g).config).options;
	}
	LA1_: ;
	if ((*result).blocks) { nimGCunrefNoCycle((*result).blocks); (*result).blocks = NIM_NIL; }
	(*result).blocks = (tySequence__oUyaggHmIX9bpJcMeoG6lpA*) newSeqRC1((&NTI__oUyaggHmIX9bpJcMeoG6lpA_), ((NI) 1));
	if ((*result).nestedTryStmts) { nimGCunrefNoCycle((*result).nestedTryStmts); (*result).nestedTryStmts = NIM_NIL; }
	if ((*result).finallySafePoints) { nimGCunrefNoCycle((*result).finallySafePoints); (*result).finallySafePoints = NIM_NIL; }
	initCountTable__c8ZqFh8t3EqhDNTipW6ekQ(((NI) 32), (&(*result).sigConflicts));
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!eqStrings((*i), item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__CWgb1wQSxTCKtdHVU5pCYQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, includeHeader__G5jzmdnwglHVk5qfDcXonA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* this_0, NimStringDesc* header) {
	{
		NIM_BOOL T3_;
		NI T6_;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = contains__MghwuKjQqmVLYE8A59cNGHgsystem((*this_0).headerFiles->data, ((*this_0).headerFiles ? (*this_0).headerFiles->Sup.len : 0), header);
		if (!!(T3_)) goto LA4_;
		asgnRef((void**) (&(*this_0).headerFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*this_0).headerFiles), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
		T6_ = (*this_0).headerFiles->Sup.len++;
		T7_ = (NimStringDesc*)0;
		T7_ = (*this_0).headerFiles->data[T6_]; (*this_0).headerFiles->data[T6_] = copyStringRC1(header);
		if (T7_) nimGCunrefNoCycle(T7_);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_cgendataDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[18];
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[30];
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_4_6[6];
NI TM__DSLb4IRJQoFPuHlmZwGjjQ_6;
static char* NIM_CONST TM__DSLb4IRJQoFPuHlmZwGjjQ_5[6] = {
"preventStackTrace", 
"usesThreadVars", 
"frameDeclared", 
"isHeaderFile", 
"includesStringh", 
"objHasKidsValid"};
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[16];
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_8_7[7];
NI TM__DSLb4IRJQoFPuHlmZwGjjQ_10;
static char* NIM_CONST TM__DSLb4IRJQoFPuHlmZwGjjQ_9[7] = {
"beforeRetNeeded", 
"threadVarAccessed", 
"hasCurFramePointer", 
"noSafePoints", 
"nimErrorFlagAccessed", 
"nimErrorFlagDeclared", 
"nimErrorFlagDisabled"};
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_11_3[3];
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[7];
static TNimNode* TM__DSLb4IRJQoFPuHlmZwGjjQ_13_2[2];
static TNimNode TM__DSLb4IRJQoFPuHlmZwGjjQ_0[99];

/* section: NIM_merge_TYPE_INIT3 */
NTI__CpP4eJLbv5ZwofQXpESuGA_.size = sizeof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA);
NTI__CpP4eJLbv5ZwofQXpESuGA_.align = NIM_ALIGNOF(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA);
NTI__CpP4eJLbv5ZwofQXpESuGA_.kind = 17;
NTI__CpP4eJLbv5ZwofQXpESuGA_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[0] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[1];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[1].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[1].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, mainModProcs);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[1].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[1].name = "mainModProcs";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[1] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[2];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[2].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[2].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, mainModInit);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[2].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[2].name = "mainModInit";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[2] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[3];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[3].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[3].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, otherModsInit);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[3].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[3].name = "otherModsInit";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[3] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[4];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[4].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[4].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, mainDatInit);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[4].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[4].name = "mainDatInit";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[4] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[5];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[5].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[5].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, mapping);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[5].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[5].name = "mapping";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[5] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[6];
NTI__9cG6VsX22pOhho6kxyhFVow_.size = sizeof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow);
NTI__9cG6VsX22pOhho6kxyhFVow_.align = NIM_ALIGNOF(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow);
NTI__9cG6VsX22pOhho6kxyhFVow_.kind = 17;
NTI__9cG6VsX22pOhho6kxyhFVow_.base = (&NTI__Hb6rFM0ecvtlLf2kv9aU75w_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[0] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[8];
NTI__pujFC2IN5RzE4MXkqaMD9aQ_.size = sizeof(tyArray__pujFC2IN5RzE4MXkqaMD9aQ);
NTI__pujFC2IN5RzE4MXkqaMD9aQ_.align = NIM_ALIGNOF(tyArray__pujFC2IN5RzE4MXkqaMD9aQ);
NTI__pujFC2IN5RzE4MXkqaMD9aQ_.kind = 16;
NTI__pujFC2IN5RzE4MXkqaMD9aQ_.base = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
NTI__pujFC2IN5RzE4MXkqaMD9aQ_.flags = 2;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[8].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[8].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, s);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[8].typ = (&NTI__pujFC2IN5RzE4MXkqaMD9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[8].name = "s";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[1] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[9];
NTI__9c7EibnXBApMXwrQsaaMb6Q_.size = sizeof(tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q);
NTI__9c7EibnXBApMXwrQsaaMb6Q_.align = NIM_ALIGNOF(tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q);
NTI__9c7EibnXBApMXwrQsaaMb6Q_.kind = 14;
NTI__9c7EibnXBApMXwrQsaaMb6Q_.base = 0;
NTI__9c7EibnXBApMXwrQsaaMb6Q_.flags = 3;
for (TM__DSLb4IRJQoFPuHlmZwGjjQ_6 = 0; TM__DSLb4IRJQoFPuHlmZwGjjQ_6 < 6; TM__DSLb4IRJQoFPuHlmZwGjjQ_6++) {
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_6+10].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_6+10].offset = TM__DSLb4IRJQoFPuHlmZwGjjQ_6;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_6+10].name = TM__DSLb4IRJQoFPuHlmZwGjjQ_5[TM__DSLb4IRJQoFPuHlmZwGjjQ_6];
TM__DSLb4IRJQoFPuHlmZwGjjQ_4_6[TM__DSLb4IRJQoFPuHlmZwGjjQ_6] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_6+10];
}
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[16].len = 6; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[16].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[16].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_4_6[0];
NTI__9c7EibnXBApMXwrQsaaMb6Q_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[16];
NTI__OeiqbEYQJbV4hSslyTd4XQ_.size = sizeof(tySet_tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q);
NTI__OeiqbEYQJbV4hSslyTd4XQ_.align = NIM_ALIGNOF(tySet_tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q);
NTI__OeiqbEYQJbV4hSslyTd4XQ_.kind = 19;
NTI__OeiqbEYQJbV4hSslyTd4XQ_.base = (&NTI__9c7EibnXBApMXwrQsaaMb6Q_);
NTI__OeiqbEYQJbV4hSslyTd4XQ_.flags = 3;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[17].len = 0; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[17].kind = 0;
NTI__OeiqbEYQJbV4hSslyTd4XQ_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[17];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[9].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[9].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, flags);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[9].typ = (&NTI__OeiqbEYQJbV4hSslyTd4XQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[9].name = "flags";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[2] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[18];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[18].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[18].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, module);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[18].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[18].name = "module";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[3] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[19];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[19].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[19].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, filename);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[19].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[19].name = "filename";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[4] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[20];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[20].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[20].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, cfilename);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[20].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[20].name = "cfilename";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[5] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[21];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[21].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[21].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, tmpBase);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[21].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[21].name = "tmpBase";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[6] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[22];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[22].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[22].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, typeCache);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[22].typ = (&NTI__gZ3EYQdz9coOB7ngN9a1cqwA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[22].name = "typeCache";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[7] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[23];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[23].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[23].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, typeABICache);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[23].typ = (&NTI__LWqBPbJi8sAUtgObUDu34A_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[23].name = "typeABICache";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[8] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[24];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[24].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[24].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, forwTypeCache);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[24].typ = (&NTI__gZ3EYQdz9coOB7ngN9a1cqwA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[24].name = "forwTypeCache";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[9] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[25];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[25].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[25].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, declaredThings);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[25].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[25].name = "declaredThings";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[10] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[26];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[26].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[26].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, declaredProtos);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[26].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[26].name = "declaredProtos";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[11] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[27];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[27].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[27].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, headerFiles);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[27].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[27].name = "headerFiles";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[12] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[28];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[28].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[28].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, typeInfoMarker);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[28].typ = (&NTI__gZ3EYQdz9coOB7ngN9a1cqwA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[28].name = "typeInfoMarker";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[13] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[29];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[29].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[29].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, typeInfoMarkerV2);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[29].typ = (&NTI__gZ3EYQdz9coOB7ngN9a1cqwA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[29].name = "typeInfoMarkerV2";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[14] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[30];
NTI__g7nhmFb7KltrkyRKuP8k2Q_.size = sizeof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q);
NTI__g7nhmFb7KltrkyRKuP8k2Q_.align = NIM_ALIGNOF(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q);
NTI__g7nhmFb7KltrkyRKuP8k2Q_.kind = 18;
NTI__g7nhmFb7KltrkyRKuP8k2Q_.base = 0;
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[0] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[32];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[32].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[32].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, prc);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[32].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[32].name = "prc";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[1] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[33];
NTI__LgBeaca7tT1nUR7RL1RjPQ_.size = sizeof(tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ);
NTI__LgBeaca7tT1nUR7RL1RjPQ_.align = NIM_ALIGNOF(tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ);
NTI__LgBeaca7tT1nUR7RL1RjPQ_.kind = 14;
NTI__LgBeaca7tT1nUR7RL1RjPQ_.base = 0;
NTI__LgBeaca7tT1nUR7RL1RjPQ_.flags = 3;
for (TM__DSLb4IRJQoFPuHlmZwGjjQ_10 = 0; TM__DSLb4IRJQoFPuHlmZwGjjQ_10 < 7; TM__DSLb4IRJQoFPuHlmZwGjjQ_10++) {
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_10+34].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_10+34].offset = TM__DSLb4IRJQoFPuHlmZwGjjQ_10;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_10+34].name = TM__DSLb4IRJQoFPuHlmZwGjjQ_9[TM__DSLb4IRJQoFPuHlmZwGjjQ_10];
TM__DSLb4IRJQoFPuHlmZwGjjQ_8_7[TM__DSLb4IRJQoFPuHlmZwGjjQ_10] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[TM__DSLb4IRJQoFPuHlmZwGjjQ_10+34];
}
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[41].len = 7; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[41].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[41].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_8_7[0];
NTI__LgBeaca7tT1nUR7RL1RjPQ_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[41];
NTI__7AbOk6EDToLYuZGJ19cmZSg_.size = sizeof(tySet_tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ);
NTI__7AbOk6EDToLYuZGJ19cmZSg_.align = NIM_ALIGNOF(tySet_tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ);
NTI__7AbOk6EDToLYuZGJ19cmZSg_.kind = 19;
NTI__7AbOk6EDToLYuZGJ19cmZSg_.base = (&NTI__LgBeaca7tT1nUR7RL1RjPQ_);
NTI__7AbOk6EDToLYuZGJ19cmZSg_.flags = 3;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[42].len = 0; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[42].kind = 0;
NTI__7AbOk6EDToLYuZGJ19cmZSg_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[42];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[33].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[33].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, flags);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[33].typ = (&NTI__7AbOk6EDToLYuZGJ19cmZSg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[33].name = "flags";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[2] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[43];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[43].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[43].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, lastLineInfo);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[43].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[43].name = "lastLineInfo";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[3] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[44];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[44].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[44].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, currLineInfo);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[44].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[44].name = "currLineInfo";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[4] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[45];
NTI__FxkU4d1VDodDMc9ah6Mbagw_.size = sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw);
NTI__FxkU4d1VDodDMc9ah6Mbagw_.align = NIM_ALIGNOF(tyTuple__FxkU4d1VDodDMc9ah6Mbagw);
NTI__FxkU4d1VDodDMc9ah6Mbagw_.kind = 18;
NTI__FxkU4d1VDodDMc9ah6Mbagw_.base = 0;
NTI__FxkU4d1VDodDMc9ah6Mbagw_.flags = 2;
TM__DSLb4IRJQoFPuHlmZwGjjQ_11_3[0] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[47];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[47].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[47].offset = offsetof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw, Field0);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[47].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[47].name = "Field0";
TM__DSLb4IRJQoFPuHlmZwGjjQ_11_3[1] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[48];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[48].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[48].offset = offsetof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw, Field1);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[48].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[48].name = "Field1";
TM__DSLb4IRJQoFPuHlmZwGjjQ_11_3[2] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[49];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[49].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[49].offset = offsetof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw, Field2);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[49].typ = (&NTI__hLlQjbV9bLNq5PFxYcqacsA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[49].name = "Field2";
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[46].len = 3; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[46].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[46].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_11_3[0];
NTI__FxkU4d1VDodDMc9ah6Mbagw_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[46];
NTI__KjgUMUjT3LUKOFIK4xt5ug_.size = sizeof(tySequence__KjgUMUjT3LUKOFIK4xt5ug*);
NTI__KjgUMUjT3LUKOFIK4xt5ug_.align = NIM_ALIGNOF(tySequence__KjgUMUjT3LUKOFIK4xt5ug*);
NTI__KjgUMUjT3LUKOFIK4xt5ug_.kind = 24;
NTI__KjgUMUjT3LUKOFIK4xt5ug_.base = (&NTI__FxkU4d1VDodDMc9ah6Mbagw_);
NTI__KjgUMUjT3LUKOFIK4xt5ug_.flags = 2;
NTI__KjgUMUjT3LUKOFIK4xt5ug_.marker = Marker_tySequence__KjgUMUjT3LUKOFIK4xt5ug;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[45].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[45].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, nestedTryStmts);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[45].typ = (&NTI__KjgUMUjT3LUKOFIK4xt5ug_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[45].name = "nestedTryStmts";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[5] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[50];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[50].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[50].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, finallySafePoints);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[50].typ = (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[50].name = "finallySafePoints";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[6] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[51];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[51].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[51].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, labels);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[51].typ = (&NTI__hLlQjbV9bLNq5PFxYcqacsA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[51].name = "labels";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[7] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[52];
NTI__GFhahvekTq3dDOkWyhchMA_.size = sizeof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA);
NTI__GFhahvekTq3dDOkWyhchMA_.align = NIM_ALIGNOF(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA);
NTI__GFhahvekTq3dDOkWyhchMA_.kind = 18;
NTI__GFhahvekTq3dDOkWyhchMA_.base = 0;
NTI__GFhahvekTq3dDOkWyhchMA_.flags = 2;
TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[0] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[54];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[54].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[54].offset = offsetof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA, id);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[54].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[54].name = "id";
TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[1] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[55];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[55].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[55].offset = offsetof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA, label);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[55].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[55].name = "label";
TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[2] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[56];
NTI__c9b9aKKmyKnqxZD8lAny45jg_.size = sizeof(tyArray__c9b9aKKmyKnqxZD8lAny45jg);
NTI__c9b9aKKmyKnqxZD8lAny45jg_.align = NIM_ALIGNOF(tyArray__c9b9aKKmyKnqxZD8lAny45jg);
NTI__c9b9aKKmyKnqxZD8lAny45jg_.kind = 16;
NTI__c9b9aKKmyKnqxZD8lAny45jg_.base = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
NTI__c9b9aKKmyKnqxZD8lAny45jg_.flags = 2;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[56].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[56].offset = offsetof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA, sections);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[56].typ = (&NTI__c9b9aKKmyKnqxZD8lAny45jg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[56].name = "sections";
TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[3] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[57];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[57].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[57].offset = offsetof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA, isLoop);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[57].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[57].name = "isLoop";
TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[4] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[58];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[58].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[58].offset = offsetof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA, nestedTryStmts);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[58].typ = (&NTI__kDPg4wXyR8DDyA0MeEjIsw_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[58].name = "nestedTryStmts";
TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[5] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[59];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[59].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[59].offset = offsetof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA, nestedExceptStmts);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[59].typ = (&NTI__kDPg4wXyR8DDyA0MeEjIsw_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[59].name = "nestedExceptStmts";
TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[6] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[60];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[60].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[60].offset = offsetof(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA, frameLen);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[60].typ = (&NTI__kDPg4wXyR8DDyA0MeEjIsw_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[60].name = "frameLen";
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[53].len = 7; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[53].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[53].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_12_7[0];
NTI__GFhahvekTq3dDOkWyhchMA_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[53];
NTI__oUyaggHmIX9bpJcMeoG6lpA_.size = sizeof(tySequence__oUyaggHmIX9bpJcMeoG6lpA*);
NTI__oUyaggHmIX9bpJcMeoG6lpA_.align = NIM_ALIGNOF(tySequence__oUyaggHmIX9bpJcMeoG6lpA*);
NTI__oUyaggHmIX9bpJcMeoG6lpA_.kind = 24;
NTI__oUyaggHmIX9bpJcMeoG6lpA_.base = (&NTI__GFhahvekTq3dDOkWyhchMA_);
NTI__oUyaggHmIX9bpJcMeoG6lpA_.flags = 2;
NTI__oUyaggHmIX9bpJcMeoG6lpA_.marker = Marker_tySequence__oUyaggHmIX9bpJcMeoG6lpA;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[52].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[52].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, blocks);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[52].typ = (&NTI__oUyaggHmIX9bpJcMeoG6lpA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[52].name = "blocks";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[8] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[61];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[61].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[61].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, breakIdx);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[61].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[61].name = "breakIdx";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[9] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[62];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[62].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[62].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, options);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[62].typ = (&NTI__7MnKRybmCNh5j9bDRLMkxLw_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[62].name = "options";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[10] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[63];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[63].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[63].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, module);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[63].typ = (&NTI__NkKlBfvvsMUW70DxvxLVIg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[63].name = "module";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[11] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[64];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[64].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[64].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, withinLoop);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[64].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[64].name = "withinLoop";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[12] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[65];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[65].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[65].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, splitDecls);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[65].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[65].name = "splitDecls";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[13] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[66];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[66].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[66].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, withinTryWithExcept);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[66].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[66].name = "withinTryWithExcept";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[14] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[67];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[67].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[67].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, withinBlockLeaveActions);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[67].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[67].name = "withinBlockLeaveActions";
TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[15] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[68];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[68].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[68].offset = offsetof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q, sigConflicts);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[68].typ = (&NTI__chlLjy9bvnFM9b9bSZfiIkyGg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[68].name = "sigConflicts";
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[31].len = 16; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[31].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[31].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_7_16[0];
NTI__g7nhmFb7KltrkyRKuP8k2Q_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[31];
NTI__pAZKtoy4786BGdQWfW2Iqg_.size = sizeof(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q*);
NTI__pAZKtoy4786BGdQWfW2Iqg_.align = NIM_ALIGNOF(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q*);
NTI__pAZKtoy4786BGdQWfW2Iqg_.kind = 22;
NTI__pAZKtoy4786BGdQWfW2Iqg_.base = (&NTI__g7nhmFb7KltrkyRKuP8k2Q_);
NTI__pAZKtoy4786BGdQWfW2Iqg_.marker = Marker_tyRef__pAZKtoy4786BGdQWfW2Iqg;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[30].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[30].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, initProc);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[30].typ = (&NTI__pAZKtoy4786BGdQWfW2Iqg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[30].name = "initProc";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[15] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[69];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[69].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[69].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, preInitProc);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[69].typ = (&NTI__pAZKtoy4786BGdQWfW2Iqg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[69].name = "preInitProc";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[16] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[70];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[70].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[70].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, hcrCreateTypeInfosProc);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[70].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[70].name = "hcrCreateTypeInfosProc";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[17] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[71];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[71].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[71].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, inHcrInitGuard);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[71].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[71].name = "inHcrInitGuard";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[18] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[72];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[72].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[72].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, typeStack);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[72].typ = (&NTI__Ef05srmQTDulnBdXR4Ja6Q_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[72].name = "typeStack";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[19] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[73];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[73].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[73].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, dataCache);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[73].typ = (&NTI__wN7B39cKxLpMkvKNm9bduZ0A_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[73].name = "dataCache";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[20] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[74];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[74].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[74].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, typeNodes);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[74].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[74].name = "typeNodes";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[21] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[75];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[75].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[75].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, nimTypes);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[75].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[75].name = "nimTypes";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[22] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[76];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[76].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[76].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, typeNodesName);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[76].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[76].name = "typeNodesName";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[23] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[77];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[77].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[77].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, nimTypesName);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[77].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[77].name = "nimTypesName";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[24] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[78];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[78].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[78].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, labels);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[78].typ = (&NTI__hLlQjbV9bLNq5PFxYcqacsA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[78].name = "labels";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[25] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[79];
NTI__MxT2Arb3Nlp7V9bRITO3dvg_.size = sizeof(tyArray__MxT2Arb3Nlp7V9bRITO3dvg);
NTI__MxT2Arb3Nlp7V9bRITO3dvg_.align = NIM_ALIGNOF(tyArray__MxT2Arb3Nlp7V9bRITO3dvg);
NTI__MxT2Arb3Nlp7V9bRITO3dvg_.kind = 16;
NTI__MxT2Arb3Nlp7V9bRITO3dvg_.base = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
NTI__MxT2Arb3Nlp7V9bRITO3dvg_.flags = 2;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[79].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[79].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, extensionLoaders);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[79].typ = (&NTI__MxT2Arb3Nlp7V9bRITO3dvg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[79].name = "extensionLoaders";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[26] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[80];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[80].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[80].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, injectStmt);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[80].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[80].name = "injectStmt";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[27] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[81];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[81].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[81].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, sigConflicts);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[81].typ = (&NTI__tUMxxU9cRgLolsrW9b7IBGsQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[81].name = "sigConflicts";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[28] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[82];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[82].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[82].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, g);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[82].typ = (&NTI__1nYo7zUSsqu0chwXZGtykg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[82].name = "g";
TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[29] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[83];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[83].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[83].offset = offsetof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow, ndi);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[83].typ = (&NTI__9cEuXfAnHp9bnWFK409cMtsEw_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[83].name = "ndi";
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[7].len = 30; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[7].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[7].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_3_30[0];
NTI__9cG6VsX22pOhho6kxyhFVow_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[7];
NTI__NkKlBfvvsMUW70DxvxLVIg_.size = sizeof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*);
NTI__NkKlBfvvsMUW70DxvxLVIg_.align = NIM_ALIGNOF(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*);
NTI__NkKlBfvvsMUW70DxvxLVIg_.kind = 22;
NTI__NkKlBfvvsMUW70DxvxLVIg_.base = (&NTI__9cG6VsX22pOhho6kxyhFVow_);
NTI__NkKlBfvvsMUW70DxvxLVIg_.marker = Marker_tyRef__NkKlBfvvsMUW70DxvxLVIg;
NTI__SHVxAqOYtIy7teT1q4s0zQ_.size = sizeof(tySequence__SHVxAqOYtIy7teT1q4s0zQ*);
NTI__SHVxAqOYtIy7teT1q4s0zQ_.align = NIM_ALIGNOF(tySequence__SHVxAqOYtIy7teT1q4s0zQ*);
NTI__SHVxAqOYtIy7teT1q4s0zQ_.kind = 24;
NTI__SHVxAqOYtIy7teT1q4s0zQ_.base = (&NTI__NkKlBfvvsMUW70DxvxLVIg_);
NTI__SHVxAqOYtIy7teT1q4s0zQ_.marker = Marker_tySequence__SHVxAqOYtIy7teT1q4s0zQ;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[6].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[6].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, modules);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[6].typ = (&NTI__SHVxAqOYtIy7teT1q4s0zQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[6].name = "modules";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[6] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[84];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[84].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[84].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, modulesClosed);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[84].typ = (&NTI__SHVxAqOYtIy7teT1q4s0zQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[84].name = "modulesClosed";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[7] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[85];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[85].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[85].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, forwardedProcs);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[85].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[85].name = "forwardedProcs";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[8] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[86];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[86].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[86].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, generatedHeader);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[86].typ = (&NTI__NkKlBfvvsMUW70DxvxLVIg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[86].name = "generatedHeader";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[9] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[87];
NTI__Iz0jrTw3w7v6sMzjrqs0nA_.size = sizeof(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA);
NTI__Iz0jrTw3w7v6sMzjrqs0nA_.align = NIM_ALIGNOF(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA);
NTI__Iz0jrTw3w7v6sMzjrqs0nA_.kind = 18;
NTI__Iz0jrTw3w7v6sMzjrqs0nA_.base = 0;
NTI__Iz0jrTw3w7v6sMzjrqs0nA_.flags = 2;
TM__DSLb4IRJQoFPuHlmZwGjjQ_13_2[0] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[89];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[89].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[89].offset = offsetof(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA, Field0);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[89].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[89].name = "Field0";
TM__DSLb4IRJQoFPuHlmZwGjjQ_13_2[1] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[90];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[90].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[90].offset = offsetof(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA, Field1);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[90].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[90].name = "Field1";
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[88].len = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[88].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[88].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_13_2[0];
NTI__Iz0jrTw3w7v6sMzjrqs0nA_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[88];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[87].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[87].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, typeInfoMarker);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[87].typ = (&NTI__6nOsw5R7jH72bux7HSST9bg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[87].name = "typeInfoMarker";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[10] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[91];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[91].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[91].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, typeInfoMarkerV2);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[91].typ = (&NTI__6nOsw5R7jH72bux7HSST9bg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[91].name = "typeInfoMarkerV2";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[11] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[92];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[92].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[92].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, config);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[92].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[92].name = "config";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[12] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[93];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[93].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[93].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, graph);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[93].typ = (&NTI__KfdHSsl8vyUCSI9b3inBcww_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[93].name = "graph";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[13] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[94];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[94].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[94].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, strVersion);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[94].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[94].name = "strVersion";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[14] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[95];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[95].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[95].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, seqVersion);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[95].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[95].name = "seqVersion";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[15] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[96];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[96].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[96].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, nimtv);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[96].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[96].name = "nimtv";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[16] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[97];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[97].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[97].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, nimtvDeps);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[97].typ = (&NTI__Ef05srmQTDulnBdXR4Ja6Q_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[97].name = "nimtvDeps";
TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[17] = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[98];
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[98].kind = 1;
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[98].offset = offsetof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA, nimtvDeclared);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[98].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[98].name = "nimtvDeclared";
TM__DSLb4IRJQoFPuHlmZwGjjQ_0[0].len = 18; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[0].kind = 2; TM__DSLb4IRJQoFPuHlmZwGjjQ_0[0].sons = &TM__DSLb4IRJQoFPuHlmZwGjjQ_2_18[0];
NTI__CpP4eJLbv5ZwofQXpESuGA_.node = &TM__DSLb4IRJQoFPuHlmZwGjjQ_0[0];
NTI__1nYo7zUSsqu0chwXZGtykg_.size = sizeof(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*);
NTI__1nYo7zUSsqu0chwXZGtykg_.align = NIM_ALIGNOF(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*);
NTI__1nYo7zUSsqu0chwXZGtykg_.kind = 22;
NTI__1nYo7zUSsqu0chwXZGtykg_.base = (&NTI__CpP4eJLbv5ZwofQXpESuGA_);
NTI__1nYo7zUSsqu0chwXZGtykg_.marker = Marker_tyRef__1nYo7zUSsqu0chwXZGtykg;
}

